# Add tinypress's lib into the load path
$:.unshift File.join(File.dirname(__FILE__), 'lib')

# Load external dependencies
begin
    # Nice CLI interface toolkit
    require 'thor'

    # A better ERB
    require 'erubis'

    # Manipulating filesystem via Ruby
    require 'fileutils'

    # YAML file support
    require 'yaml'

    # Pretty output
    require 'colorize'

rescue LoadError => e
  puts "Oops. Looks like you're missing the '#{e.path}' gem."
  puts "Try running 'bundle install' to resolve this."
  exit(1)
end

# Load TinyPress components
require 'tinypress/post'
require 'tinypress/site'

module TinyPress
    class Main < Thor

        desc "establish", "Generates a TinyPress blog in the current directory"
        def establish
            begin
                TinyPress::Site.generate
            rescue Exception => e
                abort_with_message( e.message )
            end
        end

        desc "publish", "Publishes content/ using provided templates/ to generate published/"
        def publish
            begin
                TinyPress::Site.publish
            rescue Exception => e
                abort_with_message( e.message )
            end
        end

        no_commands do
            def abort_with_message( message )
                puts message
                exit(1)
            end
        end
    end
end